@@ -19,7 +19,7 @@ from urllib.parse import urljoin
 
 
 class TT_API:
-    def __init__(self):
+    def __init__(self, to_users: list):
         self._appid = 'health-data'
         self._secret = '7c77496167924d4e9581d44c7dc8987a'
         self._host = 'https://ttapi.myoas.com'
@@ -27,6 +27,7 @@ class TT_API:
             "Content-Type": "application/x-www-form-urlencoded",
             "Response-Type": "application/json"
         }
+        self._to_users = to_users
 
     def __sign(self, path: str, payload: dict) -> str:
         flag = "_tt_"
@@ -38,13 +39,15 @@ class TT_API:
         # print(f"待签名字符串: {result}")
         return md5(result.encode('utf-8')).hexdigest()
 
-    def send_text(self, to_users: list, content: str):
+    def send_text(self, content: str, to_users=[]):
+        if to_users:
+            self._to_users = to_users
         api_path = '/s/api/message/notification/send'
         payload = {
             'appid': self._appid,
             'time': int(datetime.now().timestamp()),
             'from_user': self._appid,
-            'to_users': ','.join(to_users),
+            'to_users': ','.join(self._to_users),
             'msg_content': f'[{socket.gethostname()}]: {content}',
             'msg_type': '1'
         }
